@@ -98,12 +98,11 @@ panel_launcher_save_ditem (GnomeDesktopItem *ditem,
 
 	gnome_desktop_item_save (ditem, NULL, TRUE, &error);
 	if (error) {
-		panel_error_dialog (
-			screen,
-			"cannot_save_launcher",
-			_("Cannot save launcher to disk, "
-			  "the following error occured:\n\n%s"),
-			error->message);
+		panel_error_dialog (screen,
+				    "cannot_save_launcher",
+				    _("Cannot save launcher to disk"),
+				    error->message);
+
 		g_error_free (error);
 	}
 }
@@ -126,20 +125,21 @@ launch_url (Launcher *launcher)
 	screen = launcher_get_screen (launcher);
 
 	if (!url) {
-		panel_error_dialog (
-			screen,
-			"no_url_dialog",
-			_("This launch icon does not specify a url to show"));
+		panel_error_dialog (screen,
+				    "no_url_dialog",
+				    _("Cannot launch icon"),
+				    _("This launch icon does not specify a url to show."));
 		return;
 	}
 
 	egg_url_show_on_screen (url, screen, &error);
 	if (error) {
-		panel_error_dialog (
-			screen,
-			"cant_show_url_dialog",
-			_("Cannot show %s\n%s"),
-			url, error->message);
+		panel_error_dialog (screen,
+				    "cannot_show_url_dialog",
+				    _("Cannot show %s"),
+				    error->message,
+				    url);
+
 		g_clear_error (&error);
 	}
 }
@@ -167,11 +167,11 @@ launch_cb (GtkWidget *widget,
 		panel_ditem_launch (
 			item, NULL, 0, launcher_get_screen (launcher), &error);
 		if (error) {
-			panel_error_dialog (
-				launcher_get_screen (launcher),
-				"cannot_launch_icon",
-				_("<b>Cannot launch icon</b>\n\n"
-				"Details: %s"), error->message);
+			panel_error_dialog (launcher_get_screen (launcher),
+					    "cannot_launch_icon",
+					    _("Cannot launch icon"),
+					    error->message);
+
 			g_clear_error (&error);
 		}
 	}
@@ -212,11 +212,10 @@ drag_data_received_cb (GtkWidget        *widget,
 	g_strfreev (envp);
 
 	if (error) {
-		panel_error_dialog (
-			launcher_get_screen (launcher),
-			"cannot_launch_icon",
-			_("Cannot launch icon\n%s"),
-			error->message);
+		panel_error_dialog (launcher_get_screen (launcher),
+				    "cannot_launch_icon",
+				    _("Cannot launch icon"),
+				    error->message);
 		g_clear_error (&error);
 	}
 
@@ -437,10 +436,10 @@ create_launcher (const char *location)
 	launcher->dedit = NULL;
 	launcher->prop_dialog = NULL;
 	launcher->destroy_handler = 0;
+	launcher->non_writable = FALSE;
 
 	/* Icon will be setup later */
 	launcher->button = button_widget_new (NULL /* icon */,
-					      -1,
 					      FALSE,
 					      PANEL_ORIENTATION_TOP);
 
@@ -511,7 +510,7 @@ setup_button (Launcher *launcher)
 	/* Setup icon */
 	icon = gnome_desktop_item_get_string (launcher->ditem,
 					      GNOME_DESKTOP_ITEM_ICON);
-	button_widget_set_pixmap (BUTTON_WIDGET (launcher->button), icon);
+	button_widget_set_icon_name (BUTTON_WIDGET (launcher->button), icon);
 
 	/* Setup help */
 	docpath = gnome_desktop_item_get_string (launcher->ditem,
@@ -644,6 +643,9 @@ create_properties_dialog (Launcher  *launcher,
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Launcher Properties"));
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	help = gtk_dialog_add_button (
 			GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
@@ -656,6 +658,7 @@ create_properties_dialog (Launcher  *launcher,
 			GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
 	launcher->dedit = gnome_ditem_edit_new ();
+	gtk_container_set_border_width (GTK_CONTAINER (launcher->dedit), 5);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
 			    launcher->dedit, TRUE, TRUE, 0);
 
@@ -739,7 +742,8 @@ load_launcher_applet (const char       *location,
 					   GTK_STOCK_PROPERTIES,
 					   _("_Properties"));
 
-	panel_applet_add_callback (launcher->info, "help", GTK_STOCK_HELP, _("_Help"));
+	panel_widget_set_applet_expandable (panel, GTK_WIDGET (launcher->button), FALSE, TRUE);
+	panel_widget_set_applet_size_constrained (panel, GTK_WIDGET (launcher->button), TRUE);
 
 	/* setup button according to ditem */
 	setup_button (launcher);
@@ -759,6 +763,15 @@ panel_launcher_ensure_hoarded (Launcher   *launcher,
 
 	if (!strchr (launcher_location, G_DIR_SEPARATOR))
 		return; /* already hoarded */
+
+	client  = panel_gconf_get_client ();
+	profile = panel_profile_get_name ();
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "launcher_location");
+	if ( ! gconf_client_key_is_writable (client, key, NULL)) {
+		/* can't hoard */
+		launcher->non_writable = TRUE;
+		return;
+	}
 	
 	if (!(new_location = panel_launcher_get_filename (launcher_location))) {
 		const char *path;
@@ -770,13 +783,12 @@ panel_launcher_ensure_hoarded (Launcher   *launcher,
 		new_location = panel_launcher_get_filename (path);
 	}
 
-	if (!new_location)
+	if (!new_location) {
+		/* hoarding must have failed */
+		launcher->non_writable = TRUE;
 		return;
+	}
 
-	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
-
-	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "launcher_location");
 	gconf_client_set_string (client, key, new_location, NULL);
 }
 
@@ -813,9 +825,18 @@ launcher_load_from_gconf (PanelWidget *panel_widget,
 					 TRUE,
 					 id);
 
-	if (launcher)
+	if (launcher) {
 		panel_launcher_ensure_hoarded (launcher, launcher_location, id);
 
+		if (launcher->non_writable) {
+			AppletUserMenu *menu;
+			menu = panel_applet_get_callback (launcher->info->user_menu,
+							  "properties");
+			if (menu != NULL)
+				menu->sensitive = FALSE;
+		}
+	}
+
 	g_free (launcher_location);
 }
 
@@ -871,14 +892,17 @@ ask_about_launcher (const char  *file,
 				NULL);
 
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	gtk_window_set_wmclass (GTK_WINDOW (dialog),
 				"create_launcher", "Panel");
 	
 	dee = GNOME_DITEM_EDIT (gnome_ditem_edit_new ());
+	gtk_container_set_border_width (GTK_CONTAINER (dee), 5);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-			    GTK_WIDGET (dee),
-			    TRUE, TRUE, GNOME_PAD_SMALL);
+			    GTK_WIDGET (dee), TRUE, TRUE, 0);
 
 	panel->create_launcher_dialog_list = 
 					g_slist_append (panel->create_launcher_dialog_list,
@@ -1080,11 +1104,11 @@ launcher_show_help (Launcher  *launcher,
 				launcher->ditem, "X-GNOME-DocPath");
 	panel_show_gnome_kde_help (screen, docpath, &error);
 	if (error) {
-		panel_error_dialog (
-			screen,
-			"cannot_show_gnome_kde_help",
-			_("<b>Cannot display help document</b>\n\nDetails: %s"),
-			error->message);
+		panel_error_dialog (screen,
+				    "cannot_show_gnome_kde_help",
+				    _("Cannot display help document"),
+				    error->message);
+
 		g_error_free (error);
 	}
 }
