@@ -188,9 +188,6 @@ static GtkWidget * create_desktop_menu (GtkWidget *m,
 
 static void add_bonobo_applet (GtkWidget  *widget, const char *iid);
 
-static void add_kde_submenu (GtkWidget *root_menu,
-			     gboolean fake_submenus,
-			     gboolean launcher_add);
 static void add_distribution_submenu (GtkWidget *root_menu,
 				      gboolean fake_submenus,
 				      gboolean launcher_add);
@@ -198,10 +195,6 @@ static void add_distribution_submenu (GtkWidget *root_menu,
 static GtkWidget * create_add_launcher_menu (GtkWidget *menu,
 					     gboolean fake_submenus);
 
-static void setup_stock_menu_item     (GtkWidget   *item,
-				       GtkIconSize  icon_size,
-				       const char  *stock_id,
-				       const char  *title);
 static gboolean panel_menu_key_press_handler (GtkWidget   *widget,
 					      GdkEventKey *event);
 static void         make_add_submenu   (GtkWidget             *menu,
@@ -253,47 +246,41 @@ check_for_screen (GtkWidget *w, GdkEvent *ev, gpointer data)
 	return FALSE;
 }
 
-/*the most important dialog in the whole application*/
 static void
-about_cb (GtkWidget *menuitem, gpointer data)
+show_about_dialog (GtkWidget *menuitem)
 {
-	static GtkWidget *about;
-	GtkWidget *hbox, *l;
-	GdkPixbuf *logo;
-	GString *comment;
-	char *logo_file;
-	char *authors[] = {
-	  "George Lebl (jirka@5z.com)",
-	  "Jacob Berkman (jberkman@andrew.cmu.edu)",
-	  "Miguel de Icaza (miguel@kernel.org)",
-	  "Federico Mena (quartic@gimp.org)",
-	  "Tom Tromey (tromey@cygnus.com)",
-	  "Ian Main (imain@gtk.org)",
-	  "Elliot Lee (sopwith@redhat.com)",
-	  "Owen Taylor (otaylor@redhat.com)",
-	  "Mark McLoughlin (mark@skynet.ie)",
-	  "Alex Larsson (alexl@redhat.com)",
-	  "Martin Baulig (baulig@suse.de)",
-	  "Seth Nickell (snickell@stanford.edu)",
-	  "Darin Adler (darin@bentspoon.com)",
-	  "Glynn Foster (glynn.foster@sun.com)",
-	  "Stephen Browne (stephen.browne@sun.com)",
-	  "Anders Carlsson (andersca@gnu.org)",
-	  "Padraig O'Briain (padraig.obriain@sun.com)",
-	  "Ian McKellar <yakk@yakk.net>",
-	N_("Many, many others..."),
-	/* ... from the Monty Pythons show...  */
-	N_("and finally, The Knights Who Say... NI!"),
-	  NULL
-	  };
+	static GtkWidget *about = NULL;
+	char             *authors [] = {
+		"Alex Larsson (alexl@redhat.com)",
+		"Anders Carlsson (andersca@gnu.org)",
+		"Darin Adler (darin@bentspoon.com)",
+		"Elliot Lee (sopwith@redhat.com)",
+		"Federico Mena (quartic@gimp.org)",
+		"George Lebl (jirka@5z.com)",
+		"Glynn Foster (glynn.foster@sun.com)",
+		"Ian Main (imain@gtk.org)",
+		"Ian McKellar <yakk@yakk.net>",
+		"Jacob Berkman (jberkman@andrew.cmu.edu)",
+		"Mark McLoughlin (mark@skynet.ie)",
+		"Martin Baulig (baulig@suse.de)",
+		"Miguel de Icaza (miguel@kernel.org)",
+		"Owen Taylor (otaylor@redhat.com)",
+		"Padraig O'Briain (padraig.obriain@sun.com)",
+		"Seth Nickell (snickell@stanford.edu)",
+		"Stephen Browne (stephen.browne@sun.com)",
+		"Tom Tromey (tromey@cygnus.com)",
+		N_("And many, many others..."),
+		NULL
+	};
 	char *documenters[] = {
-		"Dave Mason (dcm@redhat.com)",
-		"Dan Mueth (d-mueth@uchicago.edu)",
 	        "Alexander Kirillov (kirillov@math.sunysb.edu)",
+		"Dan Mueth (d-mueth@uchicago.edu)",
+		"Dave Mason (dcm@redhat.com)",
 		NULL
 	  };
 	/* Translator credits */
 	char *translator_credits = _("translator_credits");
+	int   i;
 
 	if (about) {
 		gtk_window_set_screen (
@@ -302,44 +289,18 @@ about_cb (GtkWidget *menuitem, gpointer data)
 		return;
 	}
 
-	{
-		int i=0;
-		while (authors[i] != NULL) {
-		       	authors[i]=_(authors[i]);
-			i++;
-		}
-	}
+	for (i = 0; authors [i]; i++)
+		authors [i] = _(authors [i]);
 
-	logo = NULL;
-	logo_file = panel_pixmap_discovery ("gnome-gegl2.png",
-					    FALSE /* fallback */);
-	if (logo_file != NULL) {
-		logo = gdk_pixbuf_new_from_file (logo_file, NULL /* error */);
-		g_free (logo_file);
-	}
-
-	comment = g_string_new (_("This program is responsible for launching "
-				  "other applications, embedding small applets "
-				  "within itself, world peace, and random X crashes."));
-
-	if (commie_mode) {
-		g_string_append (comment,
-				 _("\n\nRunning in \"Lockdown\" mode.  This "
-				   "means your system administrator has "
-				   "prohibited any changes to the panel's "
-				   "configuration to take place."));
-	}
-	
-	about = gnome_about_new ( _("The GNOME Panel"), VERSION,
-			"Copyright \xc2\xa9 1997-2002 Free Software Foundation, Inc.",
-			comment->str,
-			(const char **)authors,
-			(const char **)documenters,
-			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			logo);
-
-	g_object_unref (logo);
-	g_string_free (comment, TRUE);
+	about = gnome_about_new (_("The GNOME Panel"),
+				 VERSION,
+				 "Copyright \xc2\xa9 1997-2003 Free Software Foundation, Inc.",
+				 _("This program is responsible for launching other "
+				   "applications and embedding small applets within itself."),
+				 (const char **) authors,
+				 (const char **) documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 NULL);
 
 	gtk_window_set_wmclass (GTK_WINDOW (about), "about_dialog", "Panel");
 	gtk_window_set_screen (GTK_WINDOW (about),
@@ -350,14 +311,6 @@ about_cb (GtkWidget *menuitem, gpointer data)
 	g_signal_connect (about, "event",
 			  G_CALLBACK (check_for_screen), NULL);
 
-	hbox = gtk_hbox_new (TRUE, 0);
-	l = gnome_href_new ("http://www.wfp.org/",
-			    _("End world hunger"));
-	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (about)->vbox),
-			    hbox, TRUE, FALSE, 0);
-	gtk_widget_show_all (hbox);
-
 	gtk_widget_show (about);
 }
 
@@ -370,8 +323,9 @@ about_gnome_cb (GtkWidget *menuitem,
 	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, &program_path) < 0)
 		panel_error_dialog (screen,
 				    "cannot_exec_about_gnome",
-				    _("<b>Can't execute 'About GNOME'</b>\n\n"
-				    "Details: %s probably does not exist"),
+				    _("Cannot execute '%s'"),
+				    _("%s - command not found"),
+				    _("About GNOME"),
 				    program_path);
 }
 
@@ -391,21 +345,22 @@ activate_app_def (GtkWidget  *menuitem,
 		panel_ditem_launch (
 			item, NULL, 0, menuitem_to_screen (menuitem), &error);
 		if (error) {
-			panel_error_dialog (
-				menuitem_to_screen (menuitem),
-				"cant_launch_entry",
-				_("<b>Can't launch entry</b>\n\n"
-				  "Details: %s"), error->message);
+			panel_error_dialog (menuitem_to_screen (menuitem),
+					    "cannot_launch_entry",
+					    _("Cannot launch entry"),
+					    error->message);
+
 			g_clear_error (&error);
 		}
 		gnome_desktop_item_unref (item);
 	} else {
 		g_assert (error != NULL);
-		panel_error_dialog (
-			menuitem_to_screen (menuitem),
-			"cant_load_entry",
-			_("<b>Can't load entry</b>\n\n"
-			  "Details: %s"), error->message);
+
+		panel_error_dialog (menuitem_to_screen (menuitem),
+				    "cannot_load_entry",
+				    _("Cannot load entry"),
+				    error->message);
+
 		g_clear_error (&error);
 	}
 }
@@ -717,8 +672,6 @@ panel_make_sure_menu_within_screen (GtkMenu *menu)
 
 	menu->position_func = menu_on_screen;
 	menu->position_func_data = repo;
-
-	our_gtk_menu_position (menu);
 }
 
 static void
@@ -751,33 +704,33 @@ icon_theme_changed (GnomeIconTheme *icon_theme,
 }
 
 GtkWidget *
-panel_menu_new (void)
+panel_create_menu (void)
 {
-	GtkWidget       *menu;
-	static gboolean  registred_icon_theme_changer = FALSE;
+	GtkWidget       *retval;
+	static gboolean  registered_icon_theme_changer = FALSE;
 
-	if (!registred_icon_theme_changer) {
-		registred_icon_theme_changer = TRUE;
+	if (!registered_icon_theme_changer) {
+		registered_icon_theme_changer = TRUE;
 
 		g_signal_connect (panel_icon_theme, "changed",
 				  G_CALLBACK (icon_theme_changed), NULL);
 	}
 	
-	menu = gtk_menu_new ();
-
+	retval = gtk_menu_new ();
+	
 	panel_gconf_notify_add_while_alive ("/desktop/gnome/interface/menus_have_icons",
 					    (GConfClientNotifyFunc) menus_have_icons_changed,
-					    G_OBJECT (menu));
+					    G_OBJECT (retval));
 
-	g_signal_connect_after (menu, "show",
+	g_signal_connect_after (retval, "show",
 				G_CALLBACK (panel_make_sure_menu_within_screen),
 				NULL);
 
-	g_signal_connect (menu, "key_press_event",
+	g_signal_connect (retval, "key_press_event",
 			  G_CALLBACK (panel_menu_key_press_handler),
 			  NULL);
 
-	return menu;
+	return retval;
 }
 
 static GtkWidget *
@@ -785,7 +738,7 @@ menu_new (void)
 {
 	GtkWidget *retval;
 
-	retval = panel_menu_new ();
+	retval = panel_create_menu ();
 
 	g_signal_connect (
 		retval, "show", G_CALLBACK (setup_menu_panel), NULL);
@@ -1102,13 +1055,12 @@ remove_menuitem (GtkWidget *widget, ShowItemMenu *sim)
 
 		esc = g_markup_escape_text (sim->item_loc, -1);
 
-		panel_error_dialog (
-			menuitem_to_screen (sim->menuitem),
-			"cant_remove_menu_item",
-			_("<b>Could not remove the menu item %s</b>\n\n"
-			  "Details: %s\n"), 
-			esc,
-			gnome_vfs_result_to_string (result));
+		panel_error_dialog (menuitem_to_screen (sim->menuitem),
+				    "cannot_remove_menu_item",
+				    _("Cannot remove menu item %s"),
+				    gnome_vfs_result_to_string (result),
+				    esc);
+
 		g_free (esc);
 		return;
 	}
@@ -1189,20 +1141,20 @@ add_to_run_dialog (GtkWidget    *widget,
 		if (exec != NULL)
 			panel_run_dialog_present_with_text (menuitem_to_screen (sim->menuitem), exec);
 		else
-			panel_error_dialog (
-				menuitem_to_screen (sim->menuitem),
-				"no_exec_or_url_field",
-				_("<b>Can't add to run box</b>\n\n"
-				  "Details: No 'Exec' or 'URL' field in entry"));
+			panel_error_dialog (menuitem_to_screen (sim->menuitem),
+					    "no_exec_or_url_field",
+					    _("Cannot add to run box"),
+					    _("No 'Exec' or 'URL' field in entry"));
 
 		gnome_desktop_item_unref (item);
 	} else {
 		g_assert (error != NULL);
-		panel_error_dialog (
-			menuitem_to_screen (sim->menuitem),
-			"cant_load_entry",
-			_("<b>Can't load entry</b>\n\n"
-			  "Details: %s"), error->message);
+
+		panel_error_dialog (menuitem_to_screen (sim->menuitem),
+				    "cannot_load_entry",
+				    _("Cannot load entry"),
+				    error->message);
+
 		g_clear_error (&error);
 	}
 }
@@ -1224,22 +1176,23 @@ show_help_on (GtkWidget    *widget,
 		const char *docpath = gnome_desktop_item_get_string
 			(item, "X-GNOME-DocPath");
 		if ( ! panel_show_gnome_kde_help (screen, docpath, &error)) {
-			panel_error_dialog (
-				screen,
-				"cannot_show_gnome_kde_help",
-				_("<b>Cannot display help document</b>\n\n"
-				  "Details: %s"), error->message);
+			panel_error_dialog (screen,
+					    "cannot_show_gnome_kde_help",
+					    _("Cannot display help document"),
+					    error->message);
+
 			g_clear_error (&error);
 		}
 
 		gnome_desktop_item_unref (item);
 	} else {
 		g_assert (error != NULL);
-		panel_error_dialog (
-			screen,
-			"cant_load_entry",
-			_("<b>Can't load entry</b>\n\n"
-			  "Details: %s"), error->message);
+
+		panel_error_dialog (screen,
+				    "cannot_load_entry",
+				    _("Cannot load entry"),
+				    error->message);
+
 		g_clear_error (&error);
 	}
 }
@@ -1318,7 +1271,8 @@ add_drawers_from_dir (const char *dirname, const char *name,
 			continue;
 		}
 			
-		if (is_ext2 (mfile->name, ".desktop", ".kdelnk") &&
+		if ((g_str_has_suffix (mfile->name, ".desktop") ||
+		     g_str_has_suffix (mfile->name, ".kdelnk")) &&
 		    g_file_test (filename, G_FILE_TEST_EXISTS))
 			panel_launcher_create (newpanel->toplevel, G_MAXINT/2, filename);
 	}
@@ -1459,6 +1413,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 		if (sim->type == 1) {
 			char *tmp;
+			gboolean objects_writable = panel_profile_list_is_writable (PANEL_GCONF_OBJECTS);
 
 			ii = gnome_desktop_item_new_from_uri (sim->item_loc, 0, NULL);
 
@@ -1471,15 +1426,16 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this launcher to panel"));
+					NULL, _("Add this launcher to panel"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 			g_signal_connect (menuitem, "activate",
 					  G_CALLBACK (add_app_to_panel),
 					  sim);
+			gtk_widget_set_sensitive (menuitem, objects_writable);
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Remove this item"));
+					NULL, _("Remove this item"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 			g_signal_connect (G_OBJECT(menuitem), "activate",
 					    G_CALLBACK (remove_menuitem),
@@ -1495,7 +1451,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Put into run dialog"));
+					NULL, _("Put into run dialog"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
 					       menuitem);
 			g_signal_connect (menuitem, "activate",
@@ -1516,7 +1472,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 				title = g_strdup_printf (_("Help on %s"),
 							 (name != NULL) ? name : _("Application"));
 				setup_menuitem (menuitem, panel_menu_icon_get_size (),
-						NULL, title);
+						NULL, title, FALSE);
 				g_free (title);
 				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
 						 menuitem);
@@ -1541,7 +1497,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 					   G_CALLBACK(edit_dentry),
 					   sim);
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("_Properties"));
+					NULL, _("_Properties"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 
 			gnome_desktop_item_unref (ii);
@@ -1549,6 +1505,8 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 		
 		if (sim->mf != NULL) {
 			GtkWidget *submenu;
+			gboolean objects_writable = panel_profile_list_is_writable (PANEL_GCONF_OBJECTS);
+			gboolean toplevels_writable = panel_profile_list_is_writable (PANEL_GCONF_TOPLEVELS);
 
 			if (sim->type == 0) {
 				submenu = sim->menu;
@@ -1560,7 +1518,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 				menuitem = gtk_image_menu_item_new ();
 				setup_menuitem (menuitem, panel_menu_icon_get_size (),
-						NULL, _("Entire menu"));
+						NULL, _("Entire menu"), FALSE);
 				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 				gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
 							   submenu);
@@ -1569,23 +1527,25 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL,
-					_("Add this as drawer to panel"));
+					_("Add this as drawer to panel"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 			g_signal_connect (G_OBJECT(menuitem), "activate",
 				   G_CALLBACK(add_menudrawer_to_panel),
 				   sim->mf);
+			gtk_widget_set_sensitive (menuitem, objects_writable && toplevels_writable);
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this as menu to panel"));
+					NULL, _("Add this as menu to panel"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 			g_signal_connect (G_OBJECT(menuitem), "activate",
 					   G_CALLBACK(add_menu_to_panel),
 					   sim->mf->menudir);
+			gtk_widget_set_sensitive (menuitem, objects_writable);
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add new item to this menu"));
+					NULL, _("Add new item to this menu"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 			/*when activated we must pop down the first menu*/
 			g_signal_connect_swapped (G_OBJECT (menuitem),
@@ -1611,7 +1571,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 					    G_CALLBACK (edit_direntry),
 					    sim);
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Properties"));
+					NULL, _("Properties"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 		}
 	}
@@ -1783,11 +1743,49 @@ image_menuitem_size_request (GtkWidget      *menuitem,
 	requisition->height = MAX (requisition->height, icon_height);
 }
 
+static void
+setup_mnemonic (GtkWidget *menuitem,
+		GtkWidget *old_toplevel,
+		gpointer   keyval_as_pointer)
+{
+	GtkWidget *toplevel;
+	guint      keyval;
+
+	keyval = GPOINTER_TO_UINT (keyval_as_pointer);
+
+	if (old_toplevel != NULL)
+		gtk_window_remove_mnemonic (GTK_WINDOW (old_toplevel),
+					    keyval,
+					    GTK_WIDGET (menuitem));
+
+	toplevel = gtk_widget_get_toplevel (menuitem);
+	if (GTK_WIDGET_TOPLEVEL (toplevel))
+		gtk_window_add_mnemonic (GTK_WINDOW (toplevel),
+					 keyval,
+					 GTK_WIDGET (menuitem));
+}
+
+static void
+setup_invisible_mnemonic (GtkWidget *menuitem,
+			  char       unicode_char)
+{
+	guint accel_key;
+
+	accel_key = gdk_keyval_to_lower (gdk_unicode_to_keyval (unicode_char));
+
+	g_signal_connect (menuitem, "hierarchy_changed", 
+			  G_CALLBACK (setup_mnemonic),
+			  GUINT_TO_POINTER (accel_key));
+
+	setup_mnemonic (menuitem, NULL, GUINT_TO_POINTER (accel_key));
+}
+
 static void
 setup_full_menuitem (GtkWidget   *menuitem,
 		     GtkIconSize  icon_size,
 		     GtkWidget   *image,
 		     const char  *title,
+		     gboolean     invisible_mnemonic,
 		     const char  *item_loc,
 		     MenuFinfo   *mf)
 			       
@@ -1799,8 +1797,11 @@ setup_full_menuitem (GtkWidget   *menuitem,
 	GtkWidget *label;
 
 	label = gtk_label_new_with_mnemonic (title);
-	gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
+       
+	if (invisible_mnemonic && title)
+		setup_invisible_mnemonic (menuitem, title [0]);
 	
 	gtk_container_add (GTK_CONTAINER (menuitem), label);
 
@@ -1854,9 +1855,10 @@ void
 setup_menuitem (GtkWidget   *menuitem,
 		GtkIconSize  icon_size,
 		GtkWidget   *image,
-		const char  *title)
+		const char  *title,
+		gboolean     invisible_mnemonic)
 {
-	setup_full_menuitem (menuitem, icon_size, image, title, NULL, NULL);
+	setup_full_menuitem (menuitem, icon_size, image, title, invisible_mnemonic, NULL, NULL);
 }
 
 static void
@@ -2164,16 +2166,15 @@ create_menuitem (GtkWidget *menu,
 		 int *first_item,
 		 MenuFinfo *mf)
 {
-	GtkWidget *menuitem, *sub;
-	char *itemname;
+	GtkWidget  *menuitem, *sub;
 	const char *icon, *fallback;
+	char       *itemname;
 	
 	g_return_val_if_fail (fr != NULL, FALSE);
 
 	if(fr->type == FILE_REC_EXTRA)
 		return FALSE;
 
-
 	sub = NULL;
 	if(fr->fullname) {
 		itemname = g_strdup(fr->fullname);
@@ -2232,13 +2233,12 @@ create_menuitem (GtkWidget *menu,
 	if (sub)
 	        setup_full_menuitem (
 			menuitem, panel_menu_icon_get_size (),
-			NULL, itemname, NULL, mf);
+			NULL, itemname, TRUE, NULL, mf);
 
 	else 
 	        setup_full_menuitem (
 			menuitem, panel_menu_icon_get_size(),
-			NULL, itemname, fr->name, mf);
-
+			NULL, itemname, TRUE, fr->name, mf);
 
 	if(*add_separator) {
 		add_menu_separator(menu);
@@ -2401,7 +2401,9 @@ applet_menu_get_category_icon (const char *untranslated_category)
 
 static GtkWidget *
 applet_menu_append (GtkWidget  *menu,
-		    AppletMenuInfo *applet)
+		    AppletMenuInfo *applet,
+		    gboolean applets_writable,
+		    gboolean objects_writable)
 {
 	GtkWidget *menuitem;
 
@@ -2411,7 +2413,7 @@ applet_menu_append (GtkWidget  *menu,
 		panel_load_menu_image_deferred (
 			menuitem, GTK_ICON_SIZE_MENU, applet->stock_icon, applet->icon, NULL, FALSE);
 	
-	setup_full_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, applet->name, NULL, NULL);
+	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, applet->name, TRUE);
 
 	gtk_widget_show_all (menuitem);
 
@@ -2421,16 +2423,22 @@ applet_menu_append (GtkWidget  *menu,
 		gtk_tooltips_set_tip (panel_tooltips, menuitem, applet->description, NULL);
 	
 	if (applet->action_type != PANEL_ACTION_NONE) {
-		setup_internal_applet_drag (menuitem, applet->drag_data);
+		/* only allow dragging objects if we can add objects */
+		if (panel_profile_list_is_writable (PANEL_GCONF_OBJECTS))
+			setup_internal_applet_drag (menuitem, applet->drag_data);
 
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (add_action_button_to_panel),
 				  GINT_TO_POINTER (applet->action_type));
+		gtk_widget_set_sensitive (menuitem, objects_writable);
 	} else {
-		setup_applet_drag (menuitem, applet->drag_data);
+		/* only allow dragging applets if we can add applets */
+		if (panel_profile_list_is_writable (PANEL_GCONF_APPLETS))
+			setup_applet_drag (menuitem, applet->drag_data);
 		
 		g_signal_connect_data (menuitem, "activate", G_CALLBACK (add_bonobo_applet),
 				       g_strdup (applet->drag_data), (GClosureNotify) g_free, 0);
+		gtk_widget_set_sensitive (menuitem, applets_writable);
 	}
 
 	return menuitem;
@@ -2449,7 +2457,7 @@ applet_menu_append_category (GtkWidget *menu,
 		panel_load_menu_image_deferred (
 			menuitem, GTK_ICON_SIZE_MENU, stock_icon, NULL, NULL, FALSE);
 
-	setup_full_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, category, NULL, NULL);
+	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, category, TRUE);
 
 	gtk_widget_show_all (menuitem);
 
@@ -2656,10 +2664,15 @@ create_applets_menu (GtkWidget             *menu,
 	GSList            *langs_gslist;
 	GSList            *applets = NULL;
 	GSList		  *item = NULL;
+	gboolean           applets_writable;
+	gboolean           objects_writable;
 
 	if (!applet_list)
 		return NULL;
 
+	applets_writable = panel_profile_list_is_writable (PANEL_GCONF_APPLETS);
+	objects_writable = panel_profile_list_is_writable (PANEL_GCONF_OBJECTS);
+
 	if (!menu)
 		menu = menu_new ();
 
@@ -2722,7 +2735,9 @@ create_applets_menu (GtkWidget             *menu,
 		item = item->next;
 		
 		if (string_empty (applet->category)) {
-			applet_menu_append (menu, applet);
+			applet_menu_append (menu, applet,
+					    applets_writable,
+					    objects_writable);
 			continue;
 		}
 
@@ -2739,7 +2754,9 @@ create_applets_menu (GtkWidget             *menu,
 			gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), prev_menu);
 		}
 
-		applet_menu_append (prev_menu, applet);
+		applet_menu_append (prev_menu, applet,
+				    applets_writable,
+				    objects_writable);
 		
 		if (!applet->static_data)
 			g_free (applet);
@@ -2757,17 +2774,18 @@ create_new_panel (GtkWidget *menuitem)
 	panel_profile_create_toplevel ();
 }
 
-static void
+void
 setup_stock_menu_item (GtkWidget   *item,
 		       GtkIconSize  icon_size,
 		       const char  *stock_id,
-		       const char  *title)
+		       const char  *title,
+		       gboolean     invisible_mnemonic)
 {
 	if (stock_id)
 		panel_load_menu_image_deferred (
 			item, icon_size, stock_id, NULL, NULL, FALSE);
 
-	setup_menuitem (item, icon_size, NULL, title);
+	setup_menuitem (item, icon_size, NULL, title, invisible_mnemonic);
 }
 	  
 static GtkWidget *
@@ -2813,32 +2831,6 @@ create_distribution_menu (GtkWidget *menu,
 	return menu;
 }
 
-static GtkWidget *
-create_kde_menu (GtkWidget *menu, gboolean fake_submenus,
-		 gboolean force, gboolean fake,
-		 gboolean launcher_add)
-{
-	char *uri;
-
-	uri = gnome_vfs_get_uri_from_local_path (kde_menudir);
-
-	if (!fake || menu)
-		menu = create_menu_at (menu, 
-				       uri,
-				       launcher_add,
-				       _("KDE Menu"), 
-				       fake_submenus,
-				       force);
-	else
-		menu = create_fake_menu_at (uri,
-					    launcher_add,
-					    _("KDE Menu"));
-
-	g_free (uri);
-
-	return menu;
-}
-
 static GtkWidget *
 create_add_launcher_menu (GtkWidget *menu, gboolean fake_submenus)
 {
@@ -2862,10 +2854,6 @@ create_add_launcher_menu (GtkWidget *menu, gboolean fake_submenus)
 
 	add_distribution_submenu (menu, fake_submenus,
 				  TRUE /*launcher_add */);
-	if (g_file_test (kde_menudir, G_FILE_TEST_IS_DIR)) {
-		add_kde_submenu (menu, fake_submenus,
-				 TRUE /*launcher_add */);
-	}
 
 	return menu;
 }
@@ -2881,10 +2869,10 @@ remove_panel (GtkWidget *menuitem,
 	toplevel     = panel_widget->toplevel;
 
 	if (panel_toplevel_is_last_unattached (toplevel)) {
-		panel_error_dialog (
-			menuitem_to_screen (menuitem),
-			"cannot_remove_last_panel",
-			_("You cannot remove your last panel."));
+		panel_error_dialog (menuitem_to_screen (menuitem),
+				    "cannot_remove_last_panel",
+				    _("You cannot remove your last panel."),
+				    NULL);
 		return;
 	}
 
@@ -2908,15 +2896,20 @@ setup_remove_this_panel (GtkWidget *menu,
 {
 	PanelWidget *panel_widget;
 	GtkWidget   *label;
+	gboolean     toplevels_writable;
 
 	panel_widget = menu_get_panel (menu);
 
 	g_assert (PANEL_IS_TOPLEVEL (panel_widget->toplevel));
 
+	toplevels_writable = panel_profile_list_is_writable (PANEL_GCONF_TOPLEVELS);
+
 	if (panel_toplevel_is_last_unattached (panel_widget->toplevel))
 		gtk_widget_set_sensitive(menuitem, FALSE);
 	else
-		gtk_widget_set_sensitive(menuitem, TRUE);
+		/* this can only be sensitive if we can actually write to
+		   the toplevels list */
+		gtk_widget_set_sensitive(menuitem, toplevels_writable);
 
 	label = GTK_BIN(menuitem)->child;
 	if(GTK_IS_BOX(label)) {
@@ -2953,11 +2946,13 @@ make_panel_submenu (PanelWidget *panel_widget,
 	Bonobo_ServerInfoList *applet_list;
 	GtkWidget             *menuitem, *submenu;
 
+
 	menuitem = gtk_image_menu_item_new ();
 	setup_menuitem (menuitem,
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU),
-			_("_Add to Panel"));
+			_("_Add to Panel"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
 	submenu = menu_new ();
@@ -2966,14 +2961,23 @@ make_panel_submenu (PanelWidget *panel_widget,
 
 	applet_list = instrument_add_submenu_for_reload (GTK_MENU_ITEM (menuitem), submenu);
 
-	make_add_submenu (submenu, applet_list);
+	if ( ! panel_profile_list_is_writable (PANEL_GCONF_APPLETS) &&
+	     ! panel_profile_list_is_writable (PANEL_GCONF_OBJECTS)) {
+		/* if we can't write neither applets nor objects, just
+		   completely ignore this and make the whole submenu
+		   insensitive */
+		gtk_widget_set_sensitive (menuitem, FALSE);
+	} else {
+		make_add_submenu (submenu, applet_list);
+	}
 
 	menuitem = gtk_image_menu_item_new ();
 
 	setup_menuitem (menuitem, 
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU),
-			_("_Delete This Panel"));
+			_("_Delete This Panel"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT (menuitem), "activate",
 			    G_CALLBACK (remove_panel),
@@ -2987,7 +2991,8 @@ make_panel_submenu (PanelWidget *panel_widget,
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (
 				GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU),
-			_("_Properties"));
+			_("_Properties"),
+			FALSE);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect_swapped (menuitem, "activate",
@@ -3000,11 +3005,16 @@ make_panel_submenu (PanelWidget *panel_widget,
 	setup_menuitem (menuitem, 
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU),
-			_("_New Panel"));
+			_("_New Panel"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (create_new_panel), 
 			  NULL);
+	/* this can only be sensitive if we can actually write to the
+	   toplevels list */
+	gtk_widget_set_sensitive (menuitem, 
+				  panel_profile_list_is_writable (PANEL_GCONF_TOPLEVELS));
 
 	add_menu_separator (menu);
 }
@@ -3033,7 +3043,8 @@ create_panel_context_menu (PanelWidget *panel)
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (
 				GTK_STOCK_HELP, GTK_ICON_SIZE_MENU),
-			_("_Help"));
+			_("_Help"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (show_panel_help), NULL);
@@ -3043,9 +3054,10 @@ create_panel_context_menu (PanelWidget *panel)
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (
 				GNOME_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
-			_("_About Panels"));
+			_("_About Panels"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
-	g_signal_connect (menuitem, "activate", G_CALLBACK (about_cb), NULL);
+	g_signal_connect (menuitem, "activate", G_CALLBACK (show_about_dialog), NULL);
 	
 	gnome_about = g_find_program_in_path ("gnome-about");
 	if (gnome_about) {
@@ -3056,7 +3068,8 @@ create_panel_context_menu (PanelWidget *panel)
 				GTK_ICON_SIZE_MENU,
 				gtk_image_new_from_stock (
 					GNOME_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
-				_("About _GNOME"));
+				_("About _GNOME"),
+				FALSE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
 		g_signal_connect_data (menuitem, "activate",
 				       G_CALLBACK (about_gnome_cb),
@@ -3089,53 +3102,61 @@ make_add_submenu (GtkWidget             *menu,
 		  Bonobo_ServerInfoList *applet_list)
 {
 	GtkWidget *menuitem, *m;
+	gboolean objects_writable;
+
+	objects_writable = panel_profile_list_is_writable (PANEL_GCONF_OBJECTS);
 
 	/* Add Menu */
 
-	m = create_applets_menu (menu, applet_list);
+	create_applets_menu (menu, applet_list);
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   G_CALLBACK(ask_about_launcher_cb),NULL);
 	setup_internal_applet_drag(menuitem, "LAUNCHER:ASK");
+	gtk_widget_set_sensitive (menuitem, objects_writable);
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher from menu"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher from menu"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	m = create_add_launcher_menu (NULL, TRUE);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), m);
 	g_signal_connect (G_OBJECT (m),"show",
 			  G_CALLBACK (submenu_to_display), NULL);
+	gtk_widget_set_sensitive (menuitem, objects_writable);
 
   	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Main Menu"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_MAIN_MENU, _("Main Menu"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   G_CALLBACK(add_menu_to_panel),
 			   NULL);
 	setup_internal_applet_drag(menuitem, "MENU:MAIN");
+	gtk_widget_set_sensitive (menuitem, objects_writable);
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Menu Bar"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Menu Bar"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (add_menu_bar_to_panel), NULL);
 	setup_internal_applet_drag (menuitem, "MENUBAR:NEW");
+	gtk_widget_set_sensitive (menuitem, objects_writable);
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_DRAWER, _("Drawer"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_DRAWER, _("Drawer"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   (GtkSignalFunc) add_drawer_to_panel,
 			   NULL);
 	setup_internal_applet_drag(menuitem, "DRAWER:NEW");
+	gtk_widget_set_sensitive (menuitem, objects_writable);
 }
 
 static GtkWidget *
@@ -3152,7 +3173,7 @@ create_desktop_menu (GtkWidget *menu, gboolean fake_submenus)
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_LOCKSCREEN, _("Lock Screen"));
+			PANEL_STOCK_LOCKSCREEN, _("Lock Screen"), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (panel_action_lock_screen), NULL);
@@ -3164,7 +3185,7 @@ create_desktop_menu (GtkWidget *menu, gboolean fake_submenus)
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_LOGOUT, _("Log Out"));
+		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_LOGOUT, _("Log Out"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (panel_action_logout), 0);
@@ -3198,7 +3219,8 @@ add_distribution_submenu (GtkWidget *root_menu, gboolean fake_submenus,
 	setup_stock_menu_item (menuitem,
 			       panel_menu_icon_get_size (),
 			       distribution_info->stock_icon,
-			       _(distribution_info->menu_name));
+			       _(distribution_info->menu_name),
+			       TRUE);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
@@ -3212,28 +3234,6 @@ add_distribution_submenu (GtkWidget *root_menu, gboolean fake_submenus,
 			  NULL);
 }
 
-static void
-add_kde_submenu (GtkWidget *root_menu, gboolean fake_submenus,
-		 gboolean launcher_add)
-{
-	GtkWidget *menu;
-	GtkWidget *menuitem;
-
-	menu = create_kde_menu (NULL, fake_submenus, TRUE,
-				TRUE, launcher_add);
-
-	menuitem = gtk_image_menu_item_new ();
-
-	panel_load_menu_image_deferred (
-		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_KDE, NULL, NULL, FALSE);
-
-	setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL, _("KDE Menu"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
-	g_signal_connect (G_OBJECT(menu),"show",
-			  G_CALLBACK(submenu_to_display), NULL);
-}
-
 GtkWidget *
 create_root_menu (GtkWidget   *root_menu,
 		  PanelWidget *panel,
@@ -3248,17 +3248,12 @@ create_root_menu (GtkWidget   *root_menu,
 	gboolean                has_subs;
 	gboolean                has_subs2;
 
-	if ((flags & MAIN_MENU_KDE_SUB) && !got_kde_menus ())
-		flags &= ~MAIN_MENU_KDE_SUB;
-
 	if ((flags & MAIN_MENU_DISTRIBUTION_SUB) && !got_distro_menus ())
 		flags &= ~MAIN_MENU_DISTRIBUTION_SUB;
 
-	has_inline = (flags & (MAIN_MENU_SYSTEM |
-			       MAIN_MENU_KDE));
+	has_inline = (flags & MAIN_MENU_SYSTEM);
 
-	has_subs = (flags & (MAIN_MENU_SYSTEM_SUB |
-			     MAIN_MENU_KDE_SUB));
+	has_subs = (flags & MAIN_MENU_SYSTEM_SUB);
 
 	has_subs2 = (flags & (MAIN_MENU_DESKTOP_SUB |
 			      MAIN_MENU_PANEL_SUB));
@@ -3286,9 +3281,6 @@ create_root_menu (GtkWidget   *root_menu,
 		create_distribution_menu(root_menu, fake_submenus, FALSE,
 					 FALSE /* launcher_add */);
 	}
-	if (flags & MAIN_MENU_KDE)
-		create_kde_menu(root_menu, fake_submenus, FALSE, FALSE,
-				FALSE /* launcher_add */);
 
 	/*others here*/
 
@@ -3302,7 +3294,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_GNOME_LOGO, _("Applications"));
+			PANEL_STOCK_GNOME_LOGO, _("Applications"), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		if(menu) {
 			gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
@@ -3317,17 +3309,13 @@ create_root_menu (GtkWidget   *root_menu,
 		add_distribution_submenu (root_menu, fake_submenus,
 					  FALSE /*launcher_add */);
 	}
-	if (flags & MAIN_MENU_KDE_SUB) {
-		add_kde_submenu (root_menu, fake_submenus,
-				 FALSE /*launcher_add */);
-	}
 
 	if ( ! no_run_box && extra_items) {
 		add_menu_separator (root_menu);
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_RUN, _("Run Application..."));
+			PANEL_STOCK_RUN, _("Run Application..."), TRUE);
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (panel_action_run_program),
 				  NULL);
@@ -3343,7 +3331,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_SEARCHTOOL, _("Search for Files..."));
+			PANEL_STOCK_SEARCHTOOL, _("Search for Files..."), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		gtk_tooltips_set_tip (panel_tooltips, menuitem,
 				      _("Find files, folders, and documents "
@@ -3362,7 +3350,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_SCREENSHOT, _("Screenshot..."));
+			PANEL_STOCK_SCREENSHOT, _("Take Screenshot..."), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		gtk_tooltips_set_tip (panel_tooltips, menuitem,
 				      _("Take a screenshot of your desktop"),
@@ -3380,7 +3368,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_DESKTOP, _("Desktop"));
+			PANEL_STOCK_DESKTOP, _("Desktop"), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
 	}
