@@ -154,7 +154,9 @@ panel_action_search (GtkWidget *widget)
 	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, argv) < 0)
 		panel_error_dialog (screen,
 				    "cannot_exec_gnome-search-tool",
-				    _("Cannot execute gnome-search-tool"));
+				    _("Cannot execute '%s'"),
+				    NULL,
+				    "gnome-search-tool");
 }
 
 /* Take Screenshot
@@ -170,7 +172,9 @@ panel_action_screenshot (GtkWidget *widget)
 	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, argv) < 0)
 		panel_error_dialog (screen,
 				    "cannot_exec_gnome-panel-screenshot",
-				    _("Cannot execute gnome-panel-screenshot"));
+				    _("Cannot execute '%s'"),
+				    NULL,
+				    "gnome-panel-screenshot");
 }
 
 /* Force Quit
@@ -530,6 +534,7 @@ panel_action_button_load (PanelActionButtonType  type,
 		button->priv->info, "help", GTK_STOCK_HELP, _("_Help"));
 
 	panel_widget_set_applet_expandable (panel, GTK_WIDGET (button), FALSE, TRUE);
+	panel_widget_set_applet_size_constrained (panel, GTK_WIDGET (button), TRUE);
 
 	if (actions [button->priv->type].setup_menu)
 		actions [button->priv->type].setup_menu (button);
