@@ -258,7 +258,6 @@ panel_background_monitor_tile_background (PanelBackgroundMonitor *monitor,
 					  int                     height)
 {
 	GdkPixbuf *retval;
-	ArtIRect   rect;
 	int        tilewidth, tileheight;
 
 	retval = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, width, height);
@@ -266,15 +265,35 @@ panel_background_monitor_tile_background (PanelBackgroundMonitor *monitor,
 	tilewidth  = gdk_pixbuf_get_width (monitor->gdkpixbuf);
 	tileheight = gdk_pixbuf_get_height (monitor->gdkpixbuf);
 
-	rect.x0 = 0;
-	rect.y0 = 0;
-	rect.x1 = width;
-	rect.y1 = height;
+	if (tilewidth == 1 && tileheight == 1) {
+		guchar  *pixels;
+		int      n_channels;
+		guint32  pixel = 0;
 
-	panel_gdk_pixbuf_draw_to_pixbuf_tiled (
-		monitor->gdkpixbuf, retval,
-		rect, tilewidth, tileheight,
-		0, 0, 255, GDK_INTERP_NEAREST);
+		n_channels = gdk_pixbuf_get_n_channels (monitor->gdkpixbuf);
+		pixels     = gdk_pixbuf_get_pixels (monitor->gdkpixbuf);
+
+		if (pixels) {
+			if (n_channels == 4)
+				pixel = ((guint32 *) pixels) [0];
+			else if (n_channels == 3)
+				pixel = pixels [0] << 24 | pixels [1] << 16 | pixels [2] << 8;
+		}
+
+		gdk_pixbuf_fill (retval, pixel);
+	} else {
+		ArtIRect rect;
+
+		rect.x0 = 0;
+		rect.y0 = 0;
+		rect.x1 = width;
+		rect.y1 = height;
+
+		panel_gdk_pixbuf_draw_to_pixbuf_tiled (
+			monitor->gdkpixbuf, retval,
+			rect, tilewidth, tileheight,
+			0, 0, 255, GDK_INTERP_NEAREST);
+	}
 
 	return retval;
 }
@@ -314,7 +333,6 @@ panel_background_monitor_setup_pixbuf (PanelBackgroundMonitor *monitor)
 
 		tiled = panel_background_monitor_tile_background (
 						monitor, rwidth, rheight);
-
 		g_object_unref (monitor->gdkpixbuf);
 		monitor->gdkpixbuf = tiled;
 
