@@ -39,7 +39,7 @@
 #include "panel-globals.h"
 #include "panel-profile.h"
 
-#define MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_KDE_SUB | MAIN_MENU_DISTRIBUTION_SUB)
+#define MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_DISTRIBUTION_SUB)
 
 enum {
 	PROP_0,
@@ -82,7 +82,12 @@ panel_menu_bar_append_action_item (PanelMenuBar *menubar,
 {
 	GtkWidget *item;
 
-	item = stock_menu_item_new (title, stock_id, FALSE);
+	item = gtk_image_menu_item_new ();
+	setup_stock_menu_item (item,
+			       panel_menu_icon_get_size (),
+			       stock_id,
+			       title,
+			       TRUE);
 
 	gtk_tooltips_set_tip (panel_tooltips, item, tooltip, NULL);
 
@@ -98,7 +103,7 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 {
 	GtkWidget *item;
 
-	menubar->priv->actions_menu = panel_menu_new ();
+	menubar->priv->actions_menu = panel_create_menu ();
 
 	g_signal_connect (menubar->priv->actions_menu, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
@@ -224,10 +229,7 @@ panel_menu_bar_parent_set (GtkWidget *widget,
 {
 	PanelMenuBar *menubar = PANEL_MENU_BAR (widget);
 
-	if (widget->parent && !PANEL_IS_WIDGET (widget->parent)) {
-		g_warning ("Hold it! Wait one second! This isn't a PanelWidget!");
-		return;
-	}
+	g_assert (!widget->parent || PANEL_IS_WIDGET (widget->parent));
 
 	menubar->priv->panel = (PanelWidget *) widget->parent;
 
