@@ -623,7 +623,7 @@ panel_menu_button_set_icon (PanelMenuButton *button)
 		icon_path = panel_menu_button_get_icon_for_menu_path (button);
 
 	if (icon_path)
-		button_widget_set_pixmap (BUTTON_WIDGET (button), icon_path);
+		button_widget_set_icon_name (BUTTON_WIDGET (button), icon_path);
 	else
 		button_widget_set_stock_id (BUTTON_WIDGET (button), PANEL_STOCK_MAIN_MENU);
 }
@@ -774,8 +774,8 @@ panel_menu_button_create (PanelToplevel *toplevel,
 	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "use_menu_path");
 	gconf_client_set_bool (client, key, use_menu_path, NULL);
 
-	if (menu_path) {
-		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "use_menu_path");
+	if (use_menu_path && menu_path && menu_path [0]) {
+		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "menu_path");
 		gconf_client_set_string (client, key, menu_path, NULL);
 	}
 
@@ -800,15 +800,6 @@ panel_menu_button_invoke_menu (PanelMenuButton *button,
 	panel_show_help (screen, "wgospanel.xml", "gospanel-37");
 }
 
-void
-panel_menu_button_change_orientation (PanelMenuButton  *button,
-				      PanelOrientation  orientation)
-{
-	g_return_if_fail (PANEL_IS_MENU_BUTTON (button));
-
-	button_widget_set_params (BUTTON_WIDGET (button), TRUE, orientation);
-}
-
 void
 panel_menu_button_set_dnd_enabled (PanelMenuButton *button,
 				   gboolean         dnd_enabled)
