@@ -1,6 +1,31 @@
+/*
+ * panel-shell.c: panel shell interface implementation
+ *
+ * Copyright (C) 2001 Ximian, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ *
+ * Authors:
+ *      Jacob Berkman <jacob@ximian.com>
+ */
+
 #include <config.h>
 #include <libgnome/gnome-i18n.h>
 
+#include <string.h>
 #include <gtk/gtk.h>
 
 #include "panel-shell.h"
@@ -24,17 +49,29 @@ panel_shell_register (void)
 		Bonobo_RegistrationResult  reg_res;
 		char                      *message = NULL;
 		char                      *iid;
+		char			  *display;
+		char			  *p;
 
 		panel_shell = g_object_new (PANEL_SHELL_TYPE, NULL);
 		bonobo_object_set_immortal (BONOBO_OBJECT (panel_shell), TRUE);
 
+		/* Strip off the screen portion of the display */
+		display = g_strdup (g_getenv ("DISPLAY"));
+		p = strrchr (display, ':');
+		if (p) {
+			p = strchr (p, '.');
+			if (p)
+				p [0] = '\0';
+		}
+
 		iid = bonobo_activation_make_registration_id (
-				"OAFIID:GNOME_PanelShell", g_getenv ("DISPLAY"));
+				"OAFIID:GNOME_PanelShell", display);
 
 		reg_res = bonobo_activation_active_server_register (
 				iid, BONOBO_OBJREF (panel_shell));
 
 		g_free (iid);
+		g_free (display);
 
 		switch (reg_res) {
 		case Bonobo_ACTIVATION_REG_SUCCESS:
@@ -52,8 +89,10 @@ panel_shell_register (void)
 		}
 
 		if (message) {
-			GtkWidget *dlg = panel_error_dialog
-				("panel_shell_register_error", "%s", message);
+			GtkWidget *dlg = panel_error_dialog (
+						gdk_screen_get_default (),
+						"panel_shell_register_error",
+						"%s", message);
 
 			/* FIXME: quick hack */
 			g_signal_handlers_disconnect_by_func
